==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/PRODUCTIONREQUESTPARAMETERSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PRODUCTIONREQUESTPARAMETERSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PRODUCTIONREQUESTPARAMETERSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARAMETERLISTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARAMETERLISTNAME" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRODUCTIONREQUESTPARAMETERSID_Type", propOrder = {
    "parameterlistcode",
    "parameterlistname"
})
public class PRODUCTIONREQUESTPARAMETERSID_Type {

    @XmlElement(name = "PARAMETERLISTCODE", required = true)
    protected String parameterlistcode;
    @XmlElement(name = "PARAMETERLISTNAME")
    protected String parameterlistname;

    /**
     * Obtient la valeur de la propriété parameterlistcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARAMETERLISTCODE() {
        return parameterlistcode;
    }

    /**
     * Définit la valeur de la propriété parameterlistcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARAMETERLISTCODE(String value) {
        this.parameterlistcode = value;
    }

    /**
     * Obtient la valeur de la propriété parameterlistname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARAMETERLISTNAME() {
        return parameterlistname;
    }

    /**
     * Définit la valeur de la propriété parameterlistname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARAMETERLISTNAME(String value) {
        this.parameterlistname = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/PRODUCTIONREQUESTPARAMETERSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PRODUCTIONREQUESTPARAMETERSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PRODUCTIONREQUESTPARAMETERSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARAMETERLISTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARAMETERLISTNAME" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRODUCTIONREQUESTPARAMETERSID_Type", propOrder = {
    "parameterlistcode",
    "parameterlistname"
})
public class PRODUCTIONREQUESTPARAMETERSID_Type {

    @XmlElement(name = "PARAMETERLISTCODE", required = true)
    protected String parameterlistcode;
    @XmlElement(name = "PARAMETERLISTNAME")
    protected String parameterlistname;

    /**
     * Gets the value of the parameterlistcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARAMETERLISTCODE() {
        return parameterlistcode;
    }

    /**
     * Sets the value of the parameterlistcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARAMETERLISTCODE(String value) {
        this.parameterlistcode = value;
    }

    /**
     * Gets the value of the parameterlistname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARAMETERLISTNAME() {
        return parameterlistname;
    }

    /**
     * Sets the value of the parameterlistname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARAMETERLISTNAME(String value) {
        this.parameterlistname = value;
    }

}
